/*******************************************************************************
Copyright 2016 Microchip Technology Inc. (www.microchip.com)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*******************************************************************************/

#include <xc.h>

#include <stdbool.h>

#include "buttons.h"

/*** Button Definitions *********************************************/
//      S1  is MCLR button
#define S1_PORT  PORTBbits.RB2      //
#define S2_PORT  PORTBbits.RB3      //
#define S3_PORT  PORTCbits.RC0      //
#define S4_PORT  PORTCbits.RC1      //
#define S5_PORT  PORTCbits.RC2      //
#define S6_PORT  PORTAbits.RA2      //
#define S7_PORT  PORTAbits.RA3      //
#define S8_PORT  PORTAbits.RA8      //
#define S9_PORT  PORTBbits.RB4      //
#define S10_PORT  PORTAbits.RA4     //
#define S11_PORT  PORTAbits.RA9     //
#define S12_PORT  PORTCbits.RC3     //
#define S13_PORT  PORTCbits.RC4     //
#define S14_PORT  PORTCbits.RC5     //
#define S15_PORT  PORTBbits.RB5     //
#define S16_PORT  PORTAbits.RA10    //
#define S17_PORT  PORTAbits.RA7     //

#define S1_TRIS  TRISBbits.TRISB2   //
#define S2_TRIS  TRISBbits.TRISB3   //
#define S3_TRIS  TRISCbits.TRISC0   //
#define S4_TRIS  TRISCbits.TRISC1   //
#define S5_TRIS  TRISCbits.TRISC2   //
#define S6_TRIS  TRISAbits.TRISA2   //
#define S7_TRIS  TRISAbits.TRISA3   //
#define S8_TRIS  TRISAbits.TRISA8   //
#define S9_TRIS  TRISBbits.TRISB4   //
#define S10_TRIS  TRISAbits.TRISA4   //
#define S11_TRIS  TRISAbits.TRISA9   //
#define S12_TRIS  TRISCbits.TRISC3   //
#define S13_TRIS  TRISCbits.TRISC4   //
#define S14_TRIS  TRISCbits.TRISC5   //
#define S15_TRIS  TRISBbits.TRISB5   //
#define S16_TRIS  TRISAbits.TRISA10  //
#define S17_TRIS  TRISAbits.TRISA7  //

#define BUTTON_PRESSED      0
#define BUTTON_NOT_PRESSED  1

#define PIN_INPUT           1
#define PIN_OUTPUT          0

/*********************************************************************
 * Function: bool BUTTON_IsPressed(BUTTON button);
 *
 * Overview: Returns the current state of the requested button
 *
 * PreCondition: button configured via BUTTON_SetConfiguration()
 *
 * Input: BUTTON button - enumeration of the buttons available in
 *        this demo.  They should be meaningful names and not the names
 *        of the buttons on the silk-screen on the board (as the demo
 *        code may be ported to other boards).
 *         i.e. - ButtonIsPressed(BUTTON_SEND_MESSAGE);
 *
 * Output: true if pressed; false if not pressed.
 *
 ********************************************************************/
bool BUTTON_IsPressed ( BUTTON button )
{
    switch(button)
    {
        case BUTTON_S1:
            return ( (S1_PORT == BUTTON_PRESSED) ? true : false);
        case BUTTON_S2:
            return ( (S2_PORT == BUTTON_PRESSED) ? true : false);
        case BUTTON_S3:
            return ( ( S3_PORT == BUTTON_PRESSED ) ? true : false ) ;
        case BUTTON_S4:
            return ( ( S4_PORT == BUTTON_PRESSED ) ? true : false ) ;
        case BUTTON_S5:
            return ( ( S5_PORT == BUTTON_PRESSED ) ? true : false ) ;
        case BUTTON_S6:
            return ( ( S6_PORT == BUTTON_PRESSED ) ? true : false ) ;
        case BUTTON_S7:
            return ( ( S7_PORT == BUTTON_PRESSED ) ? true : false ) ;
        case BUTTON_S8:
            return ( ( S8_PORT == BUTTON_PRESSED ) ? true : false ) ;
        case BUTTON_S9:
            return ( ( S9_PORT == BUTTON_PRESSED ) ? true : false ) ;
        case BUTTON_S10:
            return ( ( S10_PORT == BUTTON_PRESSED ) ? true : false ) ;
         case BUTTON_S11:
            return ( ( S11_PORT == BUTTON_PRESSED ) ? true : false ) ;
        case BUTTON_S12:
            return ( ( S12_PORT == BUTTON_PRESSED ) ? true : false ) ;
        case BUTTON_S13:
            return ( ( S13_PORT == BUTTON_PRESSED ) ? true : false ) ;
        case BUTTON_S14:
            return ( ( S14_PORT == BUTTON_PRESSED ) ? true : false ) ;
        case BUTTON_S15:
            return ( ( S15_PORT == BUTTON_PRESSED ) ? true : false ) ;            
        case BUTTON_S16:
            return ( ( S16_PORT == BUTTON_PRESSED ) ? true : false ) ;
        case BUTTON_S17:
            return ( ( S17_PORT == BUTTON_PRESSED ) ? true : false ) ;
            
        default:
            return false;
    }
    
    return false;
}

/*********************************************************************
* Function: void BUTTON_Enable(BUTTON button);
*
* Overview: Returns the current state of the requested button
*
* PreCondition: button configured via BUTTON_SetConfiguration()
*
* Input: BUTTON button - enumeration of the buttons available in
*        this demo.  They should be meaningful names and not the names
*        of the buttons on the silk-screen on the board (as the demo
*        code may be ported to other boards).
*         i.e. - ButtonIsPressed(BUTTON_SEND_MESSAGE);
*
* Output: None
*
********************************************************************/
void BUTTON_Enable(BUTTON button)
{
    switch(button)
    {
        case BUTTON_S1:
            S1_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S2:
            S2_TRIS = PIN_INPUT;
            break;
        case BUTTON_S3:
            S3_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S4:
            S4_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S5:
            S5_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S6:
            S6_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S7:
            S7_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S8:
            S8_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S9:
            S9_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S10:
            S10_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S11:
            S11_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S12:
            S12_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S13:
            S13_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S14:
            S14_TRIS = PIN_INPUT ;
            break ;
        case BUTTON_S15:
            S15_TRIS = PIN_INPUT ;
            break ;            
        default:
            break ;
    }
}
